/********** DEMO-SET-UP:BEGIN **********/

const envVar = {
  '.env.defaults': `
GA_README_INSPECTOR="UA-117338111-1"
API_ENDPOINT_README_SCORE="http://readme-score-api.herokuapp.com/score.json?url=&human_breakdown=false&force=false"
`,
  '.env.schema': `
API_ENDPOINT_README_SCORE=
BITBUCKET_API_BASE_URL="https://api.bitbucket.org"
GA_README_INSPECTOR=
GH_TOKEN=
GITHUB_ACCESS_TOKEN=
`,
   '.env': `
GH_TOKEN=${process.env.GITHUB_ACCESS_TOKEN}
GITHUB_ACCESS_TOKEN=${process.env.GITHUB_ACCESS_TOKEN}
`
}

const fs = require('fs-extra')
const WHITESPACE = 2

const writeMockFile = async (f, data) => {
  try {
    await fs.outputFile(f, data)
    console.log(`Created ${f}`)
  } catch (err) {
    console.error(err)
  }
}

await writeMockFile('.env.defaults', envVar['.env.defaults'])
await writeMockFile('.env.schema', envVar['.env.schema'])
await writeMockFile('.env', envVar['.env'])

const dotenvExtended = require('dotenv-extended')
const envConfig = dotenvExtended.config();
console.log('Created mocks for the required .env* files.')

/********** DEMO-SET-UP:END **********/;

const readmeInspector = require('readme-inspector@2.0.1');

readmeInspector.authenticate({
  token: envConfig.GITHUB_ACCESS_TOKEN,
  type: 'oauth'
});

let readmeInfo = await readmeInspector.getInfo({
  owner: 'commonality',
  repo: 'readme-inspector'
})

console.log(JSON.stringify(readmeInfo, null, WHITESPACE));

// ▶︎ readmeInspector.getAppraisal 
const slug = 'gregswindle/github-resource-converter'
let appraisal = await readmeInspector.getAppraisal(slug)

console.log(JSON.stringify(appraisal, null, WHITESPACE));

// ▶︎ ReadmeAppraisal.prototype.for 

const {ReadmeAppraisal} = readmeInspector
const readmeAppraisal = new ReadmeAppraisal()
appraisal = await readmeAppraisal.for(slug)

console.log(JSON.stringify(appraisal, null, WHITESPACE));

readmeInfo = await readmeInspector.check({
  owner: 'commonality',
  repo: 'readme-inspector'
})

console.log(JSON.stringify(readmeInfo, null, WHITESPACE));

const readmeInfoToHtml = async (readmeInfo) => {
  const readmeMarkdown = Buffer.from(readmeInfo.value.content, 'base64').toString()
  const {data} = await readmeInspector.api.misc.renderMarkdown({
    text: readmeMarkdown
  })
  return data
}

const readmeHtml = await readmeInfoToHtml(readmeInfo)

readmeHtml;